@@ -43,3 +43,23 @@ fullseq.POSIXt <- function(range, size, ...) {
     seq(floor_time(range[1], size), ceiling_time(range[2], size), by = size)
   }
 }
+#' @export
+fullseq.difftime <- function(range, size, ...) {
+  if (is.numeric(size)) {
+    size_seconds <- size
+  } else {
+    size_seconds <- unit_seconds(size)
+  }
+
+  input_units <- units(range)
+
+  x <- seq(
+    round_any(as.numeric(range[1], units = "secs"), size_seconds, floor),
+    round_any(as.numeric(range[2], units = "secs"), size_seconds, ceiling),
+    by = size_seconds
+  )
+
+  x <- as.difftime(x, units = "secs")
+  units(x) <- input_units
+  x
+}
