@@ -1,10 +1,9 @@
-#' Mutable ranges.
+#' Mutable ranges
 #'
 #' Mutable ranges have a two methods (`train` and `reset`), and
 #' make it possible to build up complete ranges with multiple passes.
 #'
-#' @aliases DiscreteRange ContinuousRange
-#' @export DiscreteRange ContinuousRange
+#' @export
 Range <- R6::R6Class("Range", list(
   range = NULL,
   initialize = function() {
@@ -12,22 +11,26 @@ Range <- R6::R6Class("Range", list(
   }
 ))
 
+#' @export
+#' @rdname Range
 DiscreteRange <- R6::R6Class(
   "DiscreteRange",
-  inherit = "Range",
+  inherit = Range,
   list(
     train = function(x, drop = FALSE) {
-      self$range <- train_discrete(x, range, drop)
+      self$range <- train_discrete(x, self$range, drop)
     },
     reset = function() self$range <- NULL
   )
 )
 
+#' @export
+#' @rdname Range
 ContinuousRange <- R6::R6Class(
   "ContinuousRange",
-  inherit = "Range",
+  inherit = Range,
   list(
-    train = function(x) self$range <- train_continuous(x, range),
+    train = function(x) self$range <- train_continuous(x, self$range),
     reset = function() self$range <- NULL
   )
 )
